#!/bin/bash
# graphical knoppix boot
# Copyright (c) 2004 by Fabian Franz.
# License: GPL

# Where the PID of the process is stored
PID_FILE="/var/run/splash.sh"
PID_BLOCK_FILE="/var/run/splash.fifo"

test -p $PID_BLOCK_FILE || (rm -f $PID_BLOCK_FILE; mkfifo $PID_BLOCK_FILE)

# The to be used virtual terminal
VT="8"

# the original terminal
ORIG_TTY="$2"
case $ORIG_TTY in [1-5]) ;; *) ORIG_TTY=1 ;; esac

# possible "theme"
THEME="$3"
[ -z "$THEME" ] && THEME="knoppix"

clean_exit()
{
	[ -n "$PID" ] && kill "$PID"
	rm -f $PID_FILE
	chvt $ORIG_TTY
	echo "END" > $PID_BLOCK_FILE
}

PID=""

case $1 in 
start_splash)
	# syntax is: $0 start_splash tty <theme>
	[ -r "$PID_FILE" ] && exit 1
	echo $$ > $PID_FILE
	if [ -x /cdrom/KNOPPIX/splash.sh ]
	then 
	  /cdrom/KNOPPIX/splash.sh "$VT" &
	else 
	if [ -x /usr/bin/splash-"$THEME".sh ]
	then
		/usr/bin/splash-"$THEME".sh "$VT" &
	else
	  fbi --vt $VT -q /usr/share/apps/ksplash/pics/splash_top.png &
	fi
	fi
	PID="$!"
	trap "clean_exit" EXIT
	# block for a keypress
	read -n1 </dev/tty$NR
;;

stop_splash)
	[ -r "$PID_FILE" ] || exit 1
	PID=$(cat /var/run/splash.sh)
	killall -s INT fbmngplay 2>/dev/null # first clear mng processes
	killall -s INT fbmngwalk 2>/dev/null # also clear mngwalk processes
	LC_ALL=C sleep 0.75
	kill $PID 2>/dev/null
;;
start)
	if [ -r "$PID_FILE" ]
	then 
	  echo "$(basename $0): There is already a process running. Please stop it first."
	  exit 1
	fi
	TTY=$(tty)
	openvt -c$VT -- $0 start_splash ${TTY/\/dev\/tty/}
	(read < $PID_BLOCK_FILE; sleep 1; deallocvt) &
;;
stop)
	if [ -r "$PID_FILE" ]
	then
 	  $0 stop_splash
	  LC_ALL=C sleep 0.05
	  rm -f $PID_FILE
	fi
	deallocvt
;;
*)
	echo "Usage: $(basename $0) <start | stop>"
;;
esac
